# OE: conditional switches
#(ie. use with rpm --rebuild):
#	--with ezlupdate	Compile ezlupdate
#	--with pgsql		Enable OpenFTS support

%define build_ezlupdate 0
%define build_openfts 0

# commandline overrides:
# rpm -ba|--rebuild --with 'xxx'
%{?_with_ezlupdate: %{expand: %%define build_ezlupdate 1}}
%{?_with_openfts: %{expand: %%define build_openfts 1}}

%define name	ezpublish
%define version	3.2
%define release	1mdk
%define ezroot	/var/www/html/%{name}

Summary:	The eZ publish content management system (CMS)
Name:		%{name}
Version:	%{version}
Release:	%{release}
Source0:	%{name}-%{version}-3.tar.bz2
Source1:	Z10_ezpublish.conf.bz2
Source2:	ezpublish.cron.bz2
License:	GPL
URL:		http://ez.no/
Group:		System/Servers
BuildRequires:	perl
PreReq:		rpm-helper
Requires:	apache2
Requires:	mod_php
Requires:	php-common
Requires:	php-mbstring
Requires:	php-mysql
Requires:	php-gd
Requires:	php-cli

# optional packages, but not required
#Requires:	Imagick
#Requires:	php-pgsql

%if %{build_openfts}
Requires:	php-pgsql
Requires:	perl
Requires:	perl-DBD-Pg
Requires:	perl-DBI
# "perl(Lingua::Stem::Snowball) is needed by perl-Search-OpenFTS-0.34-1mdk", where
# do I find this?
Requires:	perl-Search-OpenFTS
%endif

Provides:	CMS
Provides: 	ADVXpackage
Provides: 	AP20package
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%if %{build_ezlupdate}
BuildRequires:	libqt3-devel
Requires:	libqt3
%endif

%if !%{build_ezlupdate}
BuildArch:	noarch
%endif

%description
eZ publish is an open source content management system and
development framework. As a content management system (CMS) it's
most notable feature is its revolutionary, fully customizable, and
extendable content model. This is also what makes it suitable as a
platform for general Web development. Its stand-alone libraries
can be used for cross-platform, database independent PHP projects.

eZ publish is also well suited for news publishing, e-commerce 
(B2B and B2C), portals, and corporate Web sites, intranets, and 
extranets. eZ publish is dual licenced between GPL and the eZ 
publish professional licence. 

This package has some conditional build switches:
(ie. use with rpm --rebuild):
   --with ezlupdate  Compile ezlupdate
   --with openfts    Enable OpenFTS support

%prep

%setup -q -n %{name}-%{version}-3

# clean up CVS stuff
for i in `find . -type d -name CVS` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -r $i; fi >&/dev/null
done

# fix dir perms
find . -type d | xargs chmod 755

# fix file perms
find . -type f | xargs chmod 644

%build

%if %{build_ezlupdate}
# make the ezlupdate utility
pushd support/lupdate-ezpublish3
    export QTDIR="/usr/lib/qt3"
    $QTDIR/bin/qmake ezlupdate.pro
    %make
    cp README.txt ../../README.ezlupdate
popd
%endif

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

install -d %{buildroot}%{ezroot}
install -d %{buildroot}%{_sysconfdir}/httpd/conf.d
install -d %{buildroot}%{_sysconfdir}/cron.daily

bzcat %{SOURCE1} > %{buildroot}%{_sysconfdir}/httpd/conf.d/Z10_ezpublish.conf
bzcat %{SOURCE2} > %{buildroot}%{_sysconfdir}/cron.daily/ezpublish
chmod 755 %{buildroot}%{_sysconfdir}/cron.daily/ezpublish

%if %{build_ezlupdate}
install -d %{buildroot}%{_bindir}
install -m755 bin/linux/ezlupdate %{buildroot}%{_bindir}/ezlupdate
# do some house cleaning
rm -rf %{buildroot}%{ezroot}/bin/linux
%endif

for dir in cronjobs design doc kernel lib settings share update var; do
    cp -aRf $dir %{buildroot}%{ezroot}/
done

install -m0644 .htaccess_root %{buildroot}%{ezroot}/
install -m0644 access.php %{buildroot}%{ezroot}/
install -m0644 index.php %{buildroot}%{ezroot}/
install -m0644 pre_check.php %{buildroot}%{ezroot}/
#install -m0644 var.tgz %{buildroot}%{ezroot}/

install -d %{buildroot}%{ezroot}/bin/shell
install -m0755 bin/modfix.sh %{buildroot}%{ezroot}/bin/
install -m0755 bin/shell/*.sh %{buildroot}%{ezroot}/bin/shell/
install -m0755 runcronjobs.php %{buildroot}%{ezroot}/

%if %{build_openfts}
install -d %{buildroot}%{ezroot}/bin/openfts
install -m0755 bin/openfts/*.pl %{buildroot}%{ezroot}/bin/openfts/
%endif

# fix permisions
chmod 0777 %{buildroot}%{ezroot}/settings
chmod 0777 %{buildroot}%{ezroot}/settings/override
chmod 0777 %{buildroot}%{ezroot}/settings/siteaccess/admin
#chmod 0777 %{buildroot}%{ezroot}/settings/siteaccess/user
#chmod 0777 %{buildroot}%{ezroot}/settings/siteaccess/demo
chmod 0777 %{buildroot}%{ezroot}/design/admin/override/templates
#chmod 0777 %{buildroot}%{ezroot}/design/demo/override/templates

# create ghostfiles
touch %{buildroot}%{ezroot}/settings/override/i18n.ini.append.php
touch %{buildroot}%{ezroot}/settings/override/image.ini.append.php
touch %{buildroot}%{ezroot}/settings/override/setup.ini.append.php
touch %{buildroot}%{ezroot}/settings/override/site.ini.append.php

%post
%create_ghostfile %{ezroot}/settings/override/i18n.ini.append.php apache apache 0644
%create_ghostfile %{ezroot}/settings/override/image.ini.append.php apache apache 0644
%create_ghostfile %{ezroot}/settings/override/setup.ini.append.php apache apache 0644
%create_ghostfile %{ezroot}/settings/override/site.ini.append.php apache apache 0644

echo "NOTE: there is still a bug with the 3.2* serie, but the solution is simple. Check here:"
echo "http://ez.no/developer/ez_publish_3/forum/install_configuration/another_kernel_50_error_solved"

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE PROFESSIONAL_LICENCE README.*

%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/httpd/conf.d/Z10_ezpublish.conf
%attr(0755,root,root) %config(noreplace) %{_sysconfdir}/cron.daily/ezpublish

%attr(0755,root,root) %{ezroot}/bin/shell/clearcache.sh
%attr(0755,root,root) %{ezroot}/bin/shell/makedoc.sh
%attr(0755,root,root) %{ezroot}/bin/modfix.sh

%if %{build_openfts}
%attr(0755,root,root) %{ezroot}/bin/openfts/delete.pl
%attr(0755,root,root) %{ezroot}/bin/openfts/search.pl
%attr(0755,root,root) %{ezroot}/bin/openfts/index.pl
%attr(0755,root,root) %{ezroot}/bin/openfts/init.pl
%endif

%{ezroot}/cronjobs
%{ezroot}/design
%{ezroot}/doc
%{ezroot}/kernel
%{ezroot}/lib
#%{ezroot}/sdk
%{ezroot}/share
%{ezroot}/update
#%{ezroot}/var.tgz
%{ezroot}/*.php
%{ezroot}/.htaccess_root

# apache needs to cache into the var dir
%attr(0777,apache,apache) %dir %{ezroot}/var
%attr(0777,apache,apache) %dir %{ezroot}/var/storage
%attr(0777,apache,apache) %dir %{ezroot}/var/cache

%attr(0777,root,root) %dir %{ezroot}/settings
%attr(0777,root,root) %dir %{ezroot}/settings/override
%attr(0777,root,root) %dir %{ezroot}/settings/siteaccess/admin
#%attr(0777,root,root) %dir %{ezroot}/settings/siteaccess/user
#%attr(0777,root,root) %dir %{ezroot}/settings/siteaccess/demo
%attr(0777,root,root) %dir %{ezroot}/design/admin/override/templates
#%attr(0777,root,root) %dir %{ezroot}/design/demo/override/templates

# configuration files
%attr(0644,apache,apache) %ghost %config(noreplace) %{ezroot}/settings/override/i18n.ini.append.php
%attr(0644,apache,apache) %ghost %config(noreplace) %{ezroot}/settings/override/image.ini.append.php
%attr(0644,apache,apache) %ghost %config(noreplace) %{ezroot}/settings/override/setup.ini.append.php
%attr(0644,apache,apache) %ghost %config(noreplace) %{ezroot}/settings/override/site.ini.append.php

%attr(0666,root,root) %config(noreplace) %{ezroot}/settings/siteaccess/admin/*.append
#%attr(0666,root,root) %config(noreplace) %{ezroot}/settings/siteaccess/demo/*.append
#%attr(0666,root,root) %config(noreplace) %{ezroot}/settings/siteaccess/user/*.append
#%attr(0666,root,root) %config(noreplace) %{ezroot}/settings/siteaccess/sdk/*.append

%attr(0644,root,root) %config(noreplace) %{ezroot}/settings/*.ini

%if %{build_ezlupdate}
%attr(0755,root,root) %{_bindir}/ezlupdate
%endif

%changelog
* Tue Nov 11 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 3.2-1mdk
- 3.2-3
- fixed an annoying and stupid bug in S1
- added a note in %%post

* Wed Sep 17 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 3.2-1mdk
- 3.2
- sdk and var.tgz was removed...
- misc spec file fixes
 
* Fri Jun 27 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 3.1-2mdk
- fix requires

* Thu Jun 26 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 3.1-1mdk
- initial cooker contrib
